/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.chart;

import java.util.Collection;
import java.util.Iterator;
import java.lang.Double;

import net.moioli.drawables.Axes;
import net.moioli.drawables.Logo;

/**
 * A simple yet complete implementation of the ChartI interface.
 * It includes the xy axes, the MoioChart logo and a Legend by default.
 * 
 * @see net.moioli.chart.DrawableI
 * @see net.moioli.chart.GraphicsI
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public class DefaultChart extends AbstractChart implements ChartI {
    /**
     * Default color for this DefaultChart's elements.
     */
    private Object color = null;

    /**
     * Builds an empty DefaultChart.
     */
    public DefaultChart() {
        super();
    }

    /**
     * Builds an DefaultChart with the specified objects.
     * 
     * @param c
     *            Collection of DrawableI objects
     */
    public DefaultChart(Collection c) {
        super();
        addAll(c);
    }

    /**
     * @see net.moioli.chart.ChartI#drawMe(net.moioli.chart.GraphicsI, net.moioli.chart.IntRectangle)
     */
    public void drawMe(GraphicsI g, IntRectangle clip) {
        // Calculates the scale
        Scale s = null;
        // If minY and maxY aren't already set, try to guess them
        // (autoscale)
        if (Double.isNaN(getMaxY()) || Double.isNaN(getMinY())) {
            setMinY(Double.NaN);
            setMaxY(Double.NaN);
            s = new Scale(this, clip, getMinX(), getMaxX(), super.getPixelAccuracy());
        } else {
            s = new Scale(clip, getMinX(), getMaxX(), getMinY(), getMaxY(),
                    super.getPixelAccuracy());
        }

        // Draw the axes
        new Axes().drawMe(g, s, g.getBlackColor());

        // Draw everything else
        Iterator i = iterator();
        if (this.color == null) {
            this.color = g.getRandomColor();
        }
        while (i.hasNext()) {
            Object o = i.next();
            try {
                ((DrawableI) o).drawMe(g, s, this.color);
            } catch (ClassCastException e) {
                // Nothing to draw here
            }
        }

        // Draw the logo
        new Logo().drawMe(g, s, g.getBlackColor());
    }
}