/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.drawables;

import net.moioli.chart.GraphicsI;
import net.moioli.chart.IntPoint;
import net.moioli.chart.Scale;

/**
 * Represents an important point on the DefaultChart, it will be circled and a
 * description will be added.
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public class BigPoint extends DrawablePoint {
    /** Description of this point */
    String description = "";

    /**
     * Default constructor ((0,0), no description)
     */
    public BigPoint() {
        super();
        setX(0);
        setY(0);
        this.description = "";
    }

    /**
     * Standard constructor.
     * 
     * @param x
     *            x coordinate of the BigPoint
     * @param y
     *            y coordinate of the BigPoint
     * @param description
     *            label
     */
    public BigPoint(double x, double y, String description) {
        super();
        setX(x);
        setY(y);
        this.description = description;
    }

    /**
     * This method is automatically called by DefaultChart to draw the objects it
     * contains, so end users should never call drawMe directly. Inside this
     * method there must be all the code to draw the object on a DefaultChart, and all
     * the operations which involve scaling should be done via the passed Scale
     * object.
     * 
     * @param g
     *            the surface where this object will be drawn
     * @param s
     *            the DefaultChart's Scale object
     * @param c
     *            the color to be used for drawing
     */
    public void drawMe(GraphicsI g, Scale s, Object c) {
        super.drawMe(g, s, c);
        int dettagli = s.getDetail();

        IntPoint P = new IntPoint(s.getX(getX()), s.getY(getY()));
        g.drawCircle(P.x - dettagli, P.y - dettagli, dettagli * 2);

        // If the BigPoint has a description, let's draw that too
        if (!this.description.equals("")) {
            g.setColor(g.getBlackColor());
            g.drawString(this.description, P.x + 2 * dettagli, P.y);
        }
    }

    /**
     * Returns the description.
     * 
     * @return the description.
     */
    public String getDescription() {
        return this.description;
    }

    /**
     * Changes the point's description
     * 
     * @param description
     *            the new description
     */
    public void setDescription(String description) {
        this.description = description;
    }
}